@@ -92,7 +92,7 @@ char* charset_convert(const char* str, const char *src_charset, const char *dest
     src_ch = STR_AUTO;
   } else if (!strncasecmp(src_charset, "EUC-JP", 6) || !strncasecmp(src_charset, "EUCJP", 5)) {
     src_ch = STR_EUCJP;
-  } else if (!strcasecmp(src_charset, "SHIFT_JIS") || !strcasecmp(src_charset, "SHIFT-JIS") ||
+  } else if (!strncasecmp(src_charset, "SHIFT_JIS", 9) || !strncasecmp(src_charset, "SHIFT-JIS", 9) ||
       !strcasecmp(src_charset, "CP932") || !strcasecmp(src_charset, "WINDOWS-932") ||
       !strcasecmp(src_charset, "MS932")) {
     src_ch = STR_SJIS;
@@ -100,7 +100,7 @@ char* charset_convert(const char* str, const char *src_charset, const char *dest
     src_ch = STR_JIS;
   } else if (!strncasecmp(src_charset, "UTF-8", 5) || !strncasecmp(src_charset, "UTF8", 4)) {
     src_ch = STR_UTF8;
-  } else if (!strncasecmp(src_charset, "UTF-7-IMAP", 5) || !strncasecmp(src_charset, "UTF7-IMAP", 4)) {
+  } else if (!strncasecmp(src_charset, "UTF-7-IMAP", 10) || !strncasecmp(src_charset, "UTF7-IMAP", 9)) {
     src_ch = STR_UTF7_IMAP;
   } else if (!strncasecmp(src_charset, "UTF-7", 5) || !strncasecmp(src_charset, "UTF7", 4)) {
     src_ch = STR_UTF7;
@@ -139,7 +139,7 @@ char* charset_convert(const char* str, const char *src_charset, const char *dest
     dest_ch = "";
   } else if (!strncasecmp(dest_charset, "EUC-JP", 6) || !strncasecmp(dest_charset, "EUCJP", 5)) {
     dest_ch = STR_EUCJP;
-  } else if (!strcasecmp(dest_charset, "SHIFT_JIS") || !strcasecmp(dest_charset, "SHIFT-JIS") ||
+  } else if (!strncasecmp(dest_charset, "SHIFT_JIS", 9) || !strncasecmp(dest_charset, "SHIFT-JIS", 9) ||
       !strcasecmp(dest_charset, "CP932") || !strcasecmp(dest_charset, "WINDOWS-932") ||
       !strcasecmp(dest_charset, "MS932")) {
     dest_ch = STR_SJIS;
@@ -147,7 +147,7 @@ char* charset_convert(const char* str, const char *src_charset, const char *dest
     dest_ch = STR_JIS;
   } else if (!strncasecmp(dest_charset, "UTF-8", 5) || !strncasecmp(dest_charset, "UTF8", 4)) {
     dest_ch = STR_UTF8;
-  } else if (!strncasecmp(dest_charset, "UTF-7-IMAP", 5) || !strncasecmp(dest_charset, "UTF7-IMAP", 4)) {
+  } else if (!strncasecmp(dest_charset, "UTF-7-IMAP", 10) || !strncasecmp(dest_charset, "UTF7-IMAP", 9)) {
     dest_ch = STR_UTF7_IMAP;
   } else if (!strncasecmp(dest_charset, "UTF-7", 5) || !strncasecmp(dest_charset, "UTF7", 4)) {
     dest_ch = STR_UTF7;
@@ -2887,7 +2887,7 @@ char* utf8_to_modutf7(const char* str) {
         0,  0,  0,  0,  0,  0,  0,  0,  0,  0,  0,  0,  0,  0,  0,  0, // E
         0,  0,  0,  0,  0,  0,  0,  0,  0,  0,  0,  0,  0,  0,  0,  0  // F
   };
-  const char base64chars[] = "ABCDEFGHIJKLMNOPQRSTUVWXYZabcdefghijklmnopqrstuvwxyz0123456789+,"; // UTF7 modified base64
+  const char base64chars[] = "ABCDEFGHIJKLMNOPQRSTUVWXYZabcdefghijklmnopqrstuvwxyz0123456789+,"; // UTF-7 modified base64
   const unsigned long UTF16MASK      = 0x03FFUL;
   const unsigned long UTF16SHIFT     = 10;
   const unsigned long UTF16BASE      = 0x10000UL;
