@@ -49,6 +49,8 @@ const char* auto_detect(const char* str);
 const char* jis_auto_detect(const char* str);
 char* iso8859_to_utf8(const char* str, int iso8859_num);
 char* utf8_to_iso8859(const char* str, int iso8859_num);
+char* koi8_to_utf8(const char* str, char ch);
+char* utf8_to_koi8(const char* str, char ch);
 char* utf8_to_eucjp(const char* str);
 char* sjis_to_eucjp(const char* str);
 char* jis_to_eucjp(const char* str);
